==> ra_aid-0.14.2.tar.gz: ra_aid-0.14.2/docs/docs/intro.md <==
---
sidebar_position: 1
slug: /
---

# Welcome to RA.Aid

RA.Aid (pronounced "raid") is your AI-powered development companion that helps you build software autonomously. Whether you're working on new features, refactoring code, or researching solutions, RA.Aid makes development faster and more efficient.

## Why RA.Aid?

- 🤖 **Autonomous Development**: Let RA.Aid handle complex programming tasks while you focus on the big picture
- 🔍 **Smart Research**: Automatically researches solutions and best practices
- 📋 **Intelligent Planning**: Breaks down complex tasks into manageable steps
- 💬 **Interactive Mode**: Get help when you need it through natural conversation

## Quick Start

Ready to get started? Jump right to:

- [Installation Guide](/quickstart/installation)
- [Basic Usage Examples](/usage/modern-web-app)

### Basic Example

Here's how simple it is to use RA.Aid:

```bash
# Install RA.Aid
pip install ra-aid

# Set up API keys
export ANTHROPIC_API_KEY=your_key_here
export OPENAI_API_KEY=your_key_here
export TAVILY_API_KEY=your_key_here

# Start using it
ra-aid -m "Add input validation to the login form"
```

## Key Features

- **Three-Stage Workflow**: Research → Planning → Implementation
- **Web Research**: Automatically searches for best practices and solutions
- **Interactive Mode**: Get help when you need it through natural conversation
- **Multiple AI Providers**: Support for various AI models to suit your needs
- **Git Integration**: Works seamlessly with your version control

## Next Steps

- Check out the [Installation Guide](/quickstart/installation) to set up RA.Aid
- See [Usage Examples](/usage/modern-web-app) to get started quickly
- Read our [Contributing Guide](/contributing) to get involved
- Join our [Discord Community](https://discord.gg/f6wYbzHYxV) for help and discussions

Ready to revolutionize your development workflow? Let's get started! 🚀

==> ra_aid-0.19.0.tar.gz: ra_aid-0.19.0/docs/docs/intro.md <==
---
sidebar_position: 1
slug: /
---

# Welcome to RA.Aid

RA.Aid (pronounced "raid") is your AI-powered development companion that helps you build software autonomously. As a standalone coding agent built on LangChain's agent-based task execution framework, RA.Aid can handle research, planning, and implementation of your development tasks. Whether you're working on new features, refactoring code, or researching solutions, RA.Aid makes development faster and more efficient.

## Why RA.Aid?

- 🤖 **Autonomous Development**: Let RA.Aid handle complex programming tasks while you focus on the big picture
- 🔍 **Smart Research**: Automatically researches solutions and best practices
- 📋 **Intelligent Planning**: Breaks down complex tasks into manageable steps
- 💬 **Interactive Mode**: Get help when you need it through natural conversation

## Quick Start

Ready to get started? Jump right to:

- [Installation Guide](/quickstart/installation)
- [Basic Usage Examples](/usage/modern-web-app)

### Basic Example

Here's how simple it is to use RA.Aid:

```bash
# Install RA.Aid
pip install ra-aid

# Set up API keys
export ANTHROPIC_API_KEY=your_key_here
export OPENAI_API_KEY=your_key_here
export TAVILY_API_KEY=your_key_here

# Start using it
ra-aid -m "Add input validation to the login form"
```

## Key Features

- **Three-Stage Workflow**: Research → Planning → Implementation
- **Web Research**: Automatically searches for best practices and solutions
- **Interactive Mode**: Get help when you need it through natural conversation
- **Multiple AI Providers**: Support for various AI models to suit your needs
- **Git Integration**: Works seamlessly with your version control
- **Standalone Code Agent**: Built-in code modification capabilities by default
- **Optional Aider Integration**: Use the `--use-aider` flag to leverage aider's specialized code editing abilities

## Next Steps

- Check out the [Installation Guide](/quickstart/installation) to set up RA.Aid
- See [Usage Examples](/usage/modern-web-app) to get started quickly
- Read our [Contributing Guide](/contributing) to get involved
- Join our [Discord Community](https://discord.gg/f6wYbzHYxV) for help and discussions

Ready to revolutionize your development workflow? Let's get started! 🚀
